#ifndef TESTWIN_H
#define TESTWIN_H

#include "kswidget.h"

class TestWin : public KSWidget
{
    Q_OBJECT
public:
    TestWin();
};

#endif

